package com.ruoyi.bst.part.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.part.mapper.PartMapper;
import com.ruoyi.bst.part.domain.Part;
import com.ruoyi.bst.part.domain.PartVO;
import com.ruoyi.bst.part.domain.PartQuery;
import com.ruoyi.bst.part.service.PartService;

/**
 * 分区Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@Service
public class PartServiceImpl implements PartService
{
    @Autowired
    private PartMapper partMapper;

    /**
     * 查询分区
     *
     * @param partId 分区主键
     * @return 分区
     */
    @Override
    public PartVO selectPartByPartId(Long partId)
    {
        return partMapper.selectPartByPartId(partId);
    }

    /**
     * 查询分区列表
     *
     * @param part 分区
     * @return 分区
     */
    @Override
    public List<PartVO> selectPartList(PartQuery part)
    {
        return partMapper.selectPartList(part);
    }

    /**
     * 新增分区
     *
     * @param part 分区
     * @return 结果
     */
    @Override
    public int insertPart(Part part)
    {
        part.setCreateTime(DateUtils.getNowDate());
        return partMapper.insertPart(part);
    }

    /**
     * 修改分区
     *
     * @param part 分区
     * @return 结果
     */
    @Override
    public int updatePart(Part part)
    {
        return partMapper.updatePart(part);
    }

    /**
     * 批量删除分区
     *
     * @param partIds 需要删除的分区主键
     * @return 结果
     */
    @Override
    public int deletePartByPartIds(Long[] partIds)
    {
        return partMapper.deletePartByPartIds(partIds);
    }

    /**
     * 删除分区信息
     *
     * @param partId 分区主键
     * @return 结果
     */
    @Override
    public int deletePartByPartId(Long partId)
    {
        return partMapper.deletePartByPartId(partId);
    }
}
