package com.ruoyi.web.bst;

import com.ruoyi.bst.booth.domain.Booth;
import com.ruoyi.bst.booth.domain.BoothQuery;
import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.service.BoothService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 卡座Controller
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@RestController
@RequestMapping("/bst/booth")
public class BoothController extends BaseController
{
    @Autowired
    private BoothService boothService;

    /**
     * 查询卡座列表
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:list')")
    @GetMapping("/list")
    public TableDataInfo list(BoothQuery query)
    {
        startPage();
        startOrderBy();
        List<BoothVO> list = boothService.selectBoothList(query);
        return getDataTable(list);
    }

    /**
     * 导出卡座列表
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:export')")
    @Log(title = "卡座", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BoothQuery query)
    {
        List<BoothVO> list = boothService.selectBoothList(query);
        ExcelUtil<BoothVO> util = new ExcelUtil<BoothVO>(BoothVO.class);
        util.exportExcel(response, list, "卡座数据");
    }

    /**
     * 获取卡座详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:query')")
    @GetMapping(value = "/{boothId}")
    public AjaxResult getInfo(@PathVariable("boothId") Long boothId)
    {
        return success(boothService.selectBoothByBoothId(boothId));
    }

    /**
     * 新增卡座
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:add')")
    @Log(title = "卡座", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Booth booth)
    {
        return toAjax(boothService.insertBooth(booth));
    }

    /**
     * 修改卡座
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:edit')")
    @Log(title = "卡座", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Booth booth)
    {
        return toAjax(boothService.updateBooth(booth));
    }

    /**
     * 删除卡座
     */
    @PreAuthorize("@ss.hasPermi('bst:booth:remove')")
    @Log(title = "卡座", businessType = BusinessType.DELETE)
	@DeleteMapping("/{boothIds}")
    public AjaxResult remove(@PathVariable Long[] boothIds)
    {
        return toAjax(boothService.deleteBoothByBoothIds(boothIds));
    }
}
