package com.ruoyi.web.bst;

import com.ruoyi.bst.part.domain.Part;
import com.ruoyi.bst.part.domain.PartQuery;
import com.ruoyi.bst.part.domain.PartVO;
import com.ruoyi.bst.part.service.PartService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 分区Controller
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@RestController
@RequestMapping("/bst/part")
public class PartController extends BaseController
{
    @Autowired
    private PartService partService;

    /**
     * 查询分区列表
     */
    @PreAuthorize("@ss.hasPermi('bst:part:list')")
    @GetMapping("/list")
    public AjaxResult list(PartQuery partQuery)
    {
        List<PartVO> list = partService.selectPartList(partQuery);
        return success(list);
    }

    /**
     * 导出分区列表
     */
    @PreAuthorize("@ss.hasPermi('bst:part:export')")
    @Log(title = "分区", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PartQuery query)
    {
        List<PartVO> list = partService.selectPartList(query);
        ExcelUtil<PartVO> util = new ExcelUtil<PartVO>(PartVO.class);
        util.exportExcel(response, list, "分区数据");
    }

    /**
     * 获取分区详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:part:query')")
    @GetMapping(value = "/{partId}")
    public AjaxResult getInfo(@PathVariable("partId") Long partId)
    {
        return success(partService.selectPartByPartId(partId));
    }

    /**
     * 新增分区
     */
    @PreAuthorize("@ss.hasPermi('bst:part:add')")
    @Log(title = "分区", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Part part)
    {
        return toAjax(partService.insertPart(part));
    }

    /**
     * 修改分区
     */
    @PreAuthorize("@ss.hasPermi('bst:part:edit')")
    @Log(title = "分区", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Part part)
    {
        return toAjax(partService.updatePart(part));
    }

    /**
     * 删除分区
     */
    @PreAuthorize("@ss.hasPermi('bst:part:remove')")
    @Log(title = "分区", businessType = BusinessType.DELETE)
	@DeleteMapping("/{partIds}")
    public AjaxResult remove(@PathVariable Long[] partIds)
    {
        return toAjax(partService.deletePartByPartIds(partIds));
    }
}
